/****************************************************************************/
/*                                                                          */
/*  Function:  Show how to use the builtin random number generator.         */
/*                                                                          */
/*  Author:   Bary W Pollack                                                */
/*                                                                          */
/*  File:     Random.cpp                                                    */
/*                                                                          */
/*  Date:     06/23/98      Revised:  09/11/99                              */
/*                                                                          */
/*  Input:    None                                                          */
/*                                                                          */
/****************************************************************************/

#include <iostream.h>
#include <stdlib.h>         // access 'random()'
#include <iomanip.h>        // access 'cout.setw()'

/****************************************************************************/
/*  random -- if 'random' isn't built into your environment (in stdlib.h)   */
/*            then you can define it like this.                             */
/*            Borland users shouldn't need to include this definition.      */
/*            random(n) yields a pseudo-random number in the range 0..(n-1) */
/*            You MAY use srand() to "seed" the random number generator;    */
/*            but generally this is NOT necessary nor DESIRED.              */
/****************************************************************************/

int random (const int nSize)
{
    return ((int) ((long) nSize * rand ()) / (RAND_MAX + 1L));
}   // end random

/****************************************************************************/

int main (void)
{
    void RunRandom (const int nCount, const int nSize);

    cout << "How to use the builtin random number generator..." << endl << endl
         << "#include <stdlib.h>" << endl << endl
         << "int random(int num);" << endl << endl
         << "  random returns a random number between 0 and (num-1)." << endl
         << "  random(num) is a macro defined in stdlib.h." << endl
         << "  Both num and the random number returned are integers." << endl
         << endl
         << "-------------------------------------------------------" << endl
         << endl;

    RunRandom (100, 3);
    RunRandom (100, 10);
    RunRandom (100, 100);
    RunRandom (100, 1000);

    cout << "End Demonstration" << endl;

    return 0;
}   // end main

/****************************************************************************/

void RunRandom (const int nCount, const int nSize)
{
    cout << "Demonstrate random(" << nSize << ")...";
    for (int i = 0; i < nCount; i++)
    {
        if (i % 10 == 0)
            cout << endl;
        cout << setw (5) << random (nSize);
    }
    cout << endl << endl;
}   // end RunRandom

/****************************************************************************/

/*   Output from running this program follows...


#include <stdlib.h>

int random(int num);

  random returns a random number between 0 and (num-1).
  random(num) is a macro defined in stdlib.h.
  Both num and the random number returned are integers.

-------------------------------------------------------

Demonstrate random(3)...
    0    0    1    0    1    0    1    0    2    2
    0    1    0    2    1    0    0    2    2    2
    2    2    0    1    2    2    2    2    1    1
    1    1    1    2    0    1    0    2    1    1
    1    1    2    0    0    1    2    0    1    1
    1    0    2    0    1    1    1    1    1    0
    0    2    0    1    1    0    1    0    1    2
    0    1    0    0    0    2    1    1    0    0
    0    0    2    2    2    2    1    1    0    0
    1    1    1    0    0    2    1    2    2    0

Demonstrate random(10)...
    5    5    6    7    2    2    2    3    5    1
    6    0    9    2    8    6    7    7    5    5
    1    3    8    8    6    9    9    9    7    5
    2    7    2    6    4    1    5    3    7    3
    6    1    1    3    9    6    6    7    6    6
    7    9    4    5    3    9    0    9    4    2
    5    4    6    7    5    7    4    0    8    7
    9    4    3    9    6    5    6    2    3    8
    0    9    6    0    8    7    6    9    4    2
    6    3    3    7    9    9    2    4    9    4

Demonstrate random(100)...
   33   88   14   14   32   15   62   94   26   10
   97   24   21    8   52   87   90   26   61   89
   65    8   51   82   84   73   61   54   97   98
    6   36   72    9   68   33   11   37   25   50
    2   99    0    8   24   54   42   22   45   14
   20   41    0   46   45   18   11   42   95    5
   38    1   66   57    7    8   17   20   19   26
   35    2   74   15   87    2   22   85   91   72
   78   87   60   29   97   58   64   57   66   31
   58   20   99    6   17   53   85   11   38   18

Demonstrate random(1000)...
  931  489  404   91  646  349  255  952  128  589
  261  789  549  470  144  630  861  650  906  964
  383  448  235   30  217  692  664  556  946  988
  184   22  597  757  545   58  329  885  956   53
  827  327  399  591  846  509  291  781  910  871
  691  103  594  405  793  838  395  510  904  694
  635   29  644  716  375  808  568   65  809  600
  945  780  105  695  907   91  162   80  680  403
  251  507  126  521    9  283  307  229  759  153
  302  803  615  100  972  561  353  412  921   34

End Demonstration

*/

